#
# spec file for package ghc-th-lift
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name th-lift
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.8.5
Release:        bp160.1.7
Summary:        Derive Template Haskell's Lift class for datatypes
License:        (BSD-3-Clause OR GPL-2.0-only)
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-th-abstraction-prof
ExcludeArch:    %{ix86}

%description
Derive Template Haskell's 'Lift' class for datatypes using 'TemplateHaskell'.
The functionality in this package has largely been subsumed by the 'DeriveLift'
language extension, which is available in GHC 8.0 and later versions.
As such, this package is only useful as a way to backport bugfixes to
'DeriveLift' in later GHC versions back to older GHCs.

The following libraries are related:

* The <https://hackage.haskell.org/package/th-orphans th-orphans> package
provides instances for 'template-haskell' syntax types.

* The <http://hackage.haskell.org/package/th-lift-instances th-lift-instances>
package provides 'Lift' instances for types in 'base', 'text', 'bytestring',
'vector', etc. Some of these instances are only provided for old versions of
their respective libraries, as the same 'Lift' instances are also present
upstream on newer versions.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license COPYING
%license BSD3
%license GPL-2

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license COPYING
%license BSD3
%license GPL-2

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Oct 22 2024 Peter Simons <psimons@suse.com>
- Update th-lift to version 0.8.5.
  [#]# [0.8.5] - 2024.10.22
  * Support building with `template-haskell-2.22.1`.
  * Drop support for pre-8.0 versions of GHC.
* Sun Mar 17 2024 Peter Simons <psimons@suse.com>
- Update th-lift to version 0.8.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug  1 2023 Peter Simons <psimons@suse.com>
- Update th-lift to version 0.8.4.
  [#]# [0.8.4] - 2023.08.01
  * Add support for the `FldName` `NameSpace`, which was introduced in
    `template-haskell-2.21.0.0` (GHC 9.8).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Feb 27 2023 Peter Simons <psimons@suse.com>
- Update th-lift to version 0.8.3.
  [#]# [0.8.3] - 2023.02.27
  * Support building with `th-abstraction-0.5.*`.
  * Require `th-abstraction-0.3.0.0` or later.
* Sat Jul 23 2022 Peter Simons <psimons@suse.com>
- Update th-lift to version 0.8.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Apr 30 2021 psimons@suse.com
- Update th-lift to version 0.8.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Sep 30 2020 psimons@suse.com
- Update th-lift to version 0.8.2.
  [#]# [0.8.2] - 2020-09-29
  * Allow building with `template-haskell-2.17.0.0` (GHC 9.0).
  * Make `deriveLift` work for unlifted newtypes.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Sun Dec  8 2019 psimons@suse.com
- Update th-lift to version 0.8.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/th-lift-0.8.1/src/CHANGELOG.md
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri May 10 2019 psimons@suse.com
- Update th-lift to version 0.8.0.1.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Tue Apr 30 2019 psimons@suse.com
- Update th-lift to version 0.8.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Thu Aug 30 2018 psimons@suse.com
- Update th-lift to version 0.7.11.
  Upstream has not updated the file "Changelog" since the last
  release.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update th-lift to version 0.7.10.
  Upstream has not updated the file "Changelog" since the last
  release.
* Mon May 14 2018 psimons@suse.com
- Update th-lift to version 0.7.8.
  Upstream does not provide a changelog.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 0.7.7 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.6 revision 0 with cabal2obs.
